@@ -1,6 +1,6 @@
 package Net::Kubernetes::Role::ResourceCreator;
 # ABSTRACT: Role to allow creation of resources from either objects or files.
-$Net::Kubernetes::Role::ResourceCreator::VERSION = '1.02';
+$Net::Kubernetes::Role::ResourceCreator::VERSION = '1.03';
 use Moose::Role;
 use MooseX::Aliases;
 require YAML::XS;
@@ -49,7 +49,8 @@ sub create {
 	# true or false. This is not JSON's fault, but I'm not
 	# sure just now how I want to solve it.
 	my $content = $self->json->encode($object);
-	$content =~ s/(["'])(true|false)\1/$2/g;
+	my $validBooleanProperties = qr/readOnly(?:RootFilesystem)?|hostNetwork|hostPID|hostIPC|stdin(?:Once)?|tty|runAsNonRoot|privileged|ready|unschedulable/;
+	$content =~ s/((["'])(?:$validBooleanProperties)\2:\s)(["'])(true|false)\3/$1$4/g;
 	# /EndHack
     my $req = $self->create_request(POST=>$self->path.'/'.lc($object->{kind}).'s', undef, $content);
 	my $res = $self->ua->request($req);
@@ -82,7 +83,7 @@ Net::Kubernetes::Role::ResourceCreator - Role to allow creation of resources fro
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 METHODS
 
